@@ -6,9 +6,9 @@ Type annotations for redshift-data service client paginators.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_redshift_data import RedshiftDataAPIServiceClient
+    from mypy_boto3_redshift_data.client import RedshiftDataAPIServiceClient
     from mypy_boto3_redshift_data.paginator import (
         DescribeTablePaginator,
         GetStatementResultPaginator,
@@ -18,7 +18,8 @@ Usage::
         ListTablesPaginator,
     )
 
-    client: RedshiftDataAPIServiceClient = boto3.client("redshift-data")
+    session = Session()
+    client: RedshiftDataAPIServiceClient = session.client("redshift-data")
 
     describe_table_paginator: DescribeTablePaginator = client.get_paginator("describe_table")
     get_statement_result_paginator: GetStatementResultPaginator = client.get_paginator("get_statement_result")
@@ -66,7 +67,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeTablePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
     """
 
@@ -83,14 +84,14 @@ class DescribeTablePaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeTableResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
         """
 
 
 class GetStatementResultPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
     """
 
@@ -98,14 +99,14 @@ class GetStatementResultPaginator(Boto3Paginator):
         self, *, Id: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetStatementResultResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
         """
 
 
 class ListDatabasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
     """
 
@@ -119,14 +120,14 @@ class ListDatabasesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDatabasesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
         """
 
 
 class ListSchemasPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
     """
 
@@ -142,14 +143,14 @@ class ListSchemasPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSchemasResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
         """
 
 
 class ListStatementsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
     """
 
@@ -162,14 +163,14 @@ class ListStatementsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListStatementsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
     """
 
@@ -186,6 +187,6 @@ class ListTablesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTablesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
         """
